pub struct Network {
pub public_network_access: Option<PublicNetworkAccess>,
pub delegated_subnet_resource_id: Option<String>,
pub private_dns_zone_arm_resource_id: Option<String>,
}Expand description
Network properties of a server.
Fields
public_network_access: Option<PublicNetworkAccess>public network access is enabled or not
delegated_subnet_resource_id: Option<String>Delegated subnet arm resource id. This is required to be passed during create, in case we want the server to be VNET injected, i.e. Private access server. During update, pass this only if we want to update the value for Private DNS zone.
private_dns_zone_arm_resource_id: Option<String>Private dns zone arm resource id. This is required to be passed during create, in case we want the server to be VNET injected, i.e. Private access server. During update, pass this only if we want to update the value for Private DNS zone.
Implementations